@@ -1,8 +1,8 @@
 # $File: //member/autrijus/Locale-Maketext-Lexicon/lib/Locale/Maketext/Lexicon.pm $ $Author: autrijus $
-# $Revision: #21 $ $Change: 5469 $ $DateTime: 2003/04/27 14:18:09 $
+# $Revision: #25 $ $Change: 5487 $ $DateTime: 2003/04/28 08:18:28 $
 
 package Locale::Maketext::Lexicon;
-$Locale::Maketext::Lexicon::VERSION = '0.21';
+$Locale::Maketext::Lexicon::VERSION = '0.23';
 
 use strict;
 
@@ -12,8 +12,8 @@ Locale::Maketext::Lexicon - Use other catalog formats in Maketext
 
 =head1 VERSION
 
-This document describes version 0.21 of Locale::Maketext::Lexicon,
-released April 27, 2003.
+This document describes version 0.23 of Locale::Maketext::Lexicon,
+released April 28, 2003.
 
 =head1 SYNOPSIS
 
@@ -109,10 +109,11 @@ If I<language> begins with C<_>, it is taken as an option that
 controls how lexicons are parsed.  See L</Options> for a list
 of available options.
 
-The C<*> language is special; it must be used in conjunction
+The C<*> is a special I<language>; it must be used in conjunction
 with a filename that also contains C<*>; all matched files with
 a valid language code in the place of C<*> will be automatically
-prepared as a lexicon subclass.
+prepared as a lexicon subclass.  If there is multiple C<*> in
+the filename, the last one is used as the language name.
 
 =back
 
@@ -298,7 +299,7 @@ sub lexicon_get_ {
 	map { File::Spec->catfile($_, @subpath, $src) } @INC;
     } -1 .. $#path)[-1] unless -e $src;
 
-    die "cannot find $_[2] in \@INC" unless -e $src;
+    die "cannot find $_[1] (called by $_[2]) in \@INC" unless -e $src;
     $fh->open($src) or die $!;
     binmode($fh);
     return <$fh>;
